/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#include <MC_WDT.h>
#include <Ble_Application.h>
#include <Application.h>
#include <stdio.h>
#include <string.h>
#include <debug_serial.h>

uint16 displaydelay;

extern cy_stc_ble_gap_peer_addr_info_t remote_peer_gap_param;
cy_stc_ble_rssi_info_t remote_peer_rssi_param;

_Bool GetRssiPeer_Fn_Success;
_Bool Remote_Peerbdhandle_Rx;
uint8 rssi_read_flag;

void init_UART()
{
    /* Initialize SCB for UART operation with GUI selected settings */
    (void) Cy_SCB_UART_Init(UART_HW, &UART_config, &UART_context);
    /* Enable UART */
    Cy_SCB_UART_Enable(UART_HW);
    
    /* \x1b[2J\x1b[;H - ANSI ESC sequence for clear screen */
    printf("\x1b[2J\x1b[;H");
    /* Send welcome string */
    Cy_SCB_UART_PutString(UART_HW,"RSSI search");
    Cy_SCB_UART_Put(UART_HW,'\r');
    Cy_SCB_UART_Put(UART_HW,'\n'); 
}

int main(void)
{
    /* Initialise MCWDT for periodic interrupt every 1 second */
    MC_WDT_initialise();
    
    /* Start Host of BLE Component and register generic event handler */
    Cy_BLE_Start(StackEventHandler);
    
    /* Register IAS event handler */
    Cy_BLE_IAS_RegisterAttrCallback(IasEventHandler);
    
    /* initialise UART with interruts disabled */
    init_UART();
    
    __enable_irq(); /* Enable global interrupts. */

    /* Place your initialization/startup code here (e.g. MyInst_Start()) */ 
    
    uint8 Display_Remote_Addr=false;

    for(;;)
    {
        /* Place your application code here. */
        
        /* Cy_Ble_ProcessEvents() allows BLE stack to process pending events */
        Cy_BLE_ProcessEvents();
        
        /* Alert handler  */
        immediate_alert(); 
        
        if(DeviceConnection==true)
        {              
		static int8_t dBm=-128;
            if(Display_Remote_Addr==false)
            {
                Display_Remote_Addr=true;
                
                for(uint8 i=0;i<CY_BLE_BD_ADDR_SIZE;i++)
                {
					char tstr[20];
					snprintf(tstr, sizeof(tstr), "%x",remote_peer_gap_param.bdAddr.bdAddr[i]);
					Cy_SCB_UART_PutString(UART_HW,tstr);
                    Cy_SCB_UART_Put(UART_HW,':');
                }
                
                Cy_SCB_UART_PutString(UART_HW,"\r\n");           
                
                if(conn_param != NULL)
                {
                    remote_peer_rssi_param.bdHandle=conn_param->bdHandle;
                    Remote_Peerbdhandle_Rx=true;
                }
                else
                {
                    Remote_Peerbdhandle_Rx=false;
                    
                    Cy_SCB_UART_PutString(UART_HW,"Get peer bdhandle fail");                   
                    Cy_SCB_UART_Put(UART_HW,'\r');
                    Cy_SCB_UART_Put(UART_HW,'\n');                     
                }
            }
            
			// Get RSSI
			switch(rssi_ers)
			{
			case EVT_REQ_ACTIVE:
				Cy_BLE_GetRssiPeer(conn_param->bdHandle);
				break;
			case EVT_REQ_CMPLT:
				{ printf("RSSI = %d dBm\r\n", rssi); Cy_GPIO_Inv(Advertising_LED_0_PORT, Advertising_LED_0_NUM); }
			case EVT_REQ_IDLE:
Cy_GPIO_Write(EVT_1_PORT, EVT_1_NUM, 1);
				Cy_BLE_GetRssiPeer(conn_param->bdHandle);
				 rssi_ers = EVT_REQ_ACTIVE;
				break;
			case EVT_REQ_RFU:
				break;
			default:
				break;
			}

			if(conn_param != NULL) 
			{
			static cy_stc_ble_tx_pwr_config_param_t param;
				param.bleSsChId = CY_BLE_LL_CONN_CH_TYPE;
				param.bdHandle = conn_param->bdHandle;
			
				// Get Tx Power Level
				switch(txpwrlvl_ers)
				{
				case EVT_REQ_ACTIVE:
					Cy_BLE_GetTxPowerLevel(&param);
					break;
				case EVT_REQ_CMPLT:
					switch(txpwrlvl)
					{
    				case CY_BLE_LL_PWR_LVL_NEG_20_DBM:
						dBm = -20;
						break;
				    case CY_BLE_LL_PWR_LVL_NEG_16_DBM:
						dBm = -16;
						break;
					case CY_BLE_LL_PWR_LVL_NEG_12_DBM:
						dBm = -12;
						break;
					case CY_BLE_LL_PWR_LVL_NEG_6_DBM:
						dBm = -6;
						break;
					case CY_BLE_LL_PWR_LVL_0_DBM:
						dBm = 0;
						break;
					case CY_BLE_LL_PWR_LVL_MAX:
						dBm = 4;
						break;
					default: 
						dBm = -128;
						break;
					}
					{ printf("TxPwr = %d dBm\r\n", txpwrlvl); }
				case EVT_REQ_IDLE:
Cy_GPIO_Write(EVT_2_PORT, EVT_2_NUM, 1);
					Cy_BLE_GetTxPowerLevel(&param);
					txpwrlvl_ers = EVT_REQ_ACTIVE;
					break;
				case EVT_REQ_RFU:
					break;
				default:
					break;
				}
			}

			CyDelay(50);
			
        }
        else
        {
            Display_Remote_Addr=false; 
            displaydelay=false;
            
            Remote_Peerbdhandle_Rx=false;            
            rssi_read_flag=false;
            GetRssiPeer_Fn_Success=false;           
        }        
    }
}


/* [] END OF FILE */
